
# Human Life Programming Language (HLPL)
HLPL is a programming language for human life, it is composed from seven sofwtare:
> **Composer:** composes texts\
> **templater:** templates texts\ 
> **transcriber:** transcribes texts\
> **press:** designes web sites \
> **character:** simulates human life \
> **photographer:** simulates nature\
> **graphics:** makes graphics (movies, anime, games ...)

## Installation
This package can be installed from [PyPi](https://pypi.python.org/pypi/hlpl) by running:
```
pip install hlpl
```

## Commands line
Some line commands in HLPL:
```
hlpl
hlpl version
hlpl docs
hlpl composer
hlpl templater
hlpl transcriber
hlpl press
hlpl character
hlpl photographer
hlpl graphics
```

## Resources
HLPL comes with resources utility databases. These resources can be found at: [hlpl-resource](https://resource.hlpl.net).

## Site
> **official site:** [HLPL](https://hlpl.net) \
> **documentation:** [documentation](https://docs.hlpl.net)

**<span style="color:green">Contributions are welcome! Please github a pull request.</span>.**
## Development pattern for contributors

1. [Create a fork](https://help.github.com/articles/fork-a-repo/) of
   the [main hlpl_transcriber repository](https://github.com/hlpl) on GitHub.
2. Make your changes in a branch named something different from `master`, e.g. create
   a new branch `my-pull-request`.
3. [Create a pull request](https://help.github.com/articles/creating-a-pull-request/).

## License
HLPL is licensed under the [MIT license](https://opensource.org/licenses/MIT).
